inUnits method
Converts this quantity to a different unit.
other must have the same dimensions as this quantity.
Implementation
T inUnits(Unit unit) => q.inUnits(unit) as T;
Converts this quantity to a different unit.
other must have the same dimensions as this quantity.
T inUnits(Unit unit) => q.inUnits(unit) as T;