operator + method
Adds two quantities, converting addend to the units of this quantity.
addend must have the same dimensions as this quantity.
Implementation
Quantity operator +(Quantity addend) => Quantity.of(
value + addend._valueInUnits(unit),
unit,
);