scaled method
A copy of this quantity scaled by scalar.
scalar must be a scalar Quantity or a num.
See also DimensionedQuantity.scaled.
Implementation
Quantity scaled(Object scalar) => this * Dimensions.empty().checked(numToScalar(scalar));
A copy of this quantity scaled by scalar.
scalar must be a scalar Quantity or a num.
See also DimensionedQuantity.scaled.
Quantity scaled(Object scalar) => this * Dimensions.empty().checked(numToScalar(scalar));