Speed extension type

on
Implemented types

Constructors

Speed(Quantity q)
Speed.metresPerSecond(num value)
Speed.of(num value, Unit unit)
Speed.zero()
const

Properties

dimensions Dimensions
The dimensions of (the units of) this quantity.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNegative bool
Whether the value stored in this quantity is negative.
no setterinherited
isScalar bool
Whether this quantity is a scalar (dimensionless).
no setterinherited
isScalarSI bool
Whether this quantity is a scalar (dimensionless) in the strict SI sense.
no setterinherited
q Quantity
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sign num
The sign of the value stored in this quantity.
no setterinherited
unit Unit
finalinherited
value num
finalinherited
valueSI num
The value of this quantity in SI base scaled units.
no setterinherited

Methods

abs() Speed
An absolute value copy of this quantity.
inherited
cbrt() Quantity
A cube rooted copy of this quantity.
inherited
ceil() Speed
A ceiled copy of this quantity.
inherited
compareTo(Quantity other) int
Compares this quantity to other in common units.
inherited
cubed() Quantity
A cubed copy of this quantity.
inherited
floor() Speed
A floored copy of this quantity.
inherited
inDimensionsMaybeInverse(Dimensions other) Quantity
Converts this quantity to different dimensions, inverting if necessary.
inherited
inUnits(Unit unit) Speed
Converts this quantity to a different unit.
inherited
inUnitsMaybeInverse(Unit other) Quantity
Converts this quantity to a different unit, inverting dimensions if necessary.
inherited
inverse() Quantity
An inverted copy of this quantity, inverting both the value and unit.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
round() Speed
A rounded copy of this quantity.
inherited
scaled(Object scalar) Speed
A copy of this quantity scaled by scalar.
inherited
sqrt() Quantity
A square rooted copy of this quantity.
inherited
squared() Quantity
A squared copy of this quantity.
inherited
toNameString() String
The shortest string that correctly represents this quantity including its unit name.
inherited
toNameStringAsFixed(int fractionDigits) String
A decimal-point string representation of this quantity with its unit name.
inherited
toPrecision(int fractionDigits) Quantity
A copy of this quantity with its value rounded to fractionDigits decimal places.
inherited
toString() String
The shortest string that correctly represents this quantity including its unit symbol.
inherited
toStringAsFixed(int fractionDigits) String
A decimal-point string representation of this quantity with its unit symbol.
inherited
toStringAsFixedNoTrailing(int fractionDigits) String
A decimal-point string representation of this quantity (without trailing zeros) with its unit symbol.
inherited
truncate() Speed
A truncated copy of this quantity.
inherited

Operators

operator *(Object multiplier) Quantity
Multiplies two quantities, deriving a new unit.
inherited
operator +(Quantity addend) Speed
Adds two quantities, converting addend to the units of this quantity.
inherited
operator -(Quantity subtrahend) Speed
Subtracts two quantities, converting subtrahend to the units of this quantity.
inherited
operator /(Object divisor) Quantity
Divides two quantities, deriving a new unit.
inherited
operator <(Quantity other) bool
Whether this quantity is numerically smaller than other in common units.
inherited
operator <=(Quantity other) bool
Whether this quantity is numerically smaller than or equal to other in common units.
inherited
operator ==(Object other) bool
Test whether this quantity is equal to other.
inherited
operator >(Quantity other) bool
Whether this quantity is numerically larger than other in common units.
inherited
operator >=(Quantity other) bool
Whether this quantity is numerically larger than or equal to other in common units.
inherited
operator [](Unit unit) Speed
Converts this quantity to a different unit.
inherited
operator ^(Object exponent) Quantity
Raises this quantity to a power, raising the unit to the same power.
inherited
operator unary-() Speed
Subtracts two quantities, converting subtrahend to the units of this quantity.
inherited